@@ -3,6 +3,11 @@ print "# Setup the locale\n";
 print "unset LC_ALL\n";
 print "export LANG=${LOCALE}\n";
 print "export LANGUAGE=${LANGUAGE_PO}\n\n";
+if (${LOCALE} eq "sr_YU") {
+    if (!($CYR_ENC eq "UTF-8")) {
+	print XCYRILLIC  "export LC_MESSAGES=en_GB\n";
+    }
+}
 # print "export PATH=${MAINDIR}/bin:" . '${PATH}' . "\n";
 
 if ( $CYR_ENC eq "ISO8859-2" ) {
