@@ -7,6 +7,12 @@ print "PATH=${MAINDIR}/bin:" . '${PATH}' . "\n";
 print "export LANG\n";
 print "export LANGUAGE\n";
 print "export PATH\n\n";
+if (${LOCALE} eq "sr_YU") {
+    if (!($CYR_ENC eq "UTF-8")) {
+	print XCYRILLIC  "LC_MESSAGES=en_GB\n";
+	print XCYRILLIC  "export LC_MESSAGES\n";
+    }
+}
 
 if ( $CYR_ENC eq "ISO8859-2" ) {
     print <<'EOF';
