@@ -2,6 +2,6 @@
 Use Macedonian locale and keyboard and Cyrillic fonts in X Window.
 This setting is not needed for Debian.
 END
-Use Macedonian locale and keyboard and Cyrillic fonts in X Window.
-This setting is not needed for Debian.
+    ,     X Window.
+      Debian.
 END
