@@ -105,9 +105,9 @@ print <<'EOF';
 # ----- ߤ˱ -----
 # ls ưman ls 
 if ( $TERM == "dumb" || $TERM == "emacs" ) then
-  alias ls '/usr/bin/ls -F'
+  alias ls '/bin/ls -F'
 else
-  alias ls '/usr/bin/ls -F --color=auto'
+  alias ls '/bin/ls -F --color=auto'
 endif
 # ɸ२ǥ vi ˤ롣Debian Policy Manual 
 setenv EDITOR vi
