@@ -11,24 +11,14 @@ print <<'EOF';
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; ܸɽ
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-(if (not (boundp 'MULE))
-    (if (featurep 'xemacs)
-        ; xemacs21 ξ
-	(progn
-	  (set-language-environment "Japanese")
-	  (set-default-buffer-file-coding-system 'euc-jp-unix)
-	  (set-keyboard-coding-system 'euc-jp-unix)
-	  (if (not window-system) (set-terminal-coding-system 'euc-jp-unix))
-        )
-        ; emacs20 ξ
-        (progn
-	  (set-language-environment "Japanese")
-	  (set-default-coding-systems 'euc-japan-unix)
-	  (set-keyboard-coding-system 'euc-japan-unix)
-	  (if (not window-system) (set-terminal-coding-system 'euc-japan-unix))
-        )
-    )
-)
+(if (featurep 'mule)
+    (progn
+      (set-language-environment "Japanese")
+      (prefer-coding-system 'euc-jp-unix)
+      (set-keyboard-coding-system 'euc-jp-unix)
+      (if (not window-system) (set-terminal-coding-system 'euc-jp-unix))
+      ;;
+      ))
 ; ܸ info ʸʤ褦
 (auto-compression-mode t)
 ; xemacs  shell-mode  ܸ EUC Ȥ褦ˤ
@@ -37,9 +27,10 @@ print <<'EOF';
        (lambda () (set-buffer-process-coding-system 'euc-japan 'euc-japan))))
 )
 ; ܸ grep
-(if (file-exists-p "/usr/bin/jgrep")
-    (setq grep-command "jgrep -n -e ")
+(if (file-exists-p "/usr/bin/lgrep")
+    (setq grep-command "lgrep -n ")
 )
+
 EOF
 
 $emacs_comment = 
@@ -96,8 +87,8 @@ sub emacs_canna ($) {
 		"(global-set-key \"\\C-o\" 'toggle-input-method)\n" .
 		"(toggle-input-method nil)\n";
 	addlist("egg");
-	if (isinstalled("xemacs21.*")) {
-		addlist("xemacs21-mule-canna-wnn");
+	if (!isinstalled("emacs21") && !isinstalled("emacs21-nox")) {
+		addlist("emacs21");
 	}
 }
 
@@ -113,8 +104,8 @@ sub emacs_wnn($) {
 		"(set-input-method 'japanese-egg-wnn)\n" .
 		"(toggle-input-method nil)\n" ;
 	addlist("egg");
-	if (isinstalled("xemacs21.*")) {
-		addlist("xemacs21-mule-canna-wnn");
+	if (!isinstalled("emacs21") && !isinstalled("emacs21-nox")) {
+		addlist("emacs21");
 	}
 }
 
@@ -130,10 +121,8 @@ sub emacs_skk($) {
 	print
 		"(set-input-method \"japanese-skk\")\n" .
 		"(toggle-input-method nil)\n";
-	if (isinstalled("xemacs21.*")) {
-		if (!isinstalled("xemacs21-mule.*")) {
-			addlist("xemacs21-mule-canna-wnn");
-		}
+	if (!isinstalled("emacs21") && !isinstalled("emacs21-nox")) {
+		addlist("emacs21");
 	}
 }
 
