@@ -7,24 +7,14 @@ print <<'EOF';
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; ܸɽ
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-(if (not (boundp 'MULE))
-    (if (featurep 'xemacs)
-        ; xemacs21 ξ
-	(progn
-	  (set-language-environment "Japanese")
-	  (set-default-buffer-file-coding-system 'euc-jp-unix)
-	  (set-keyboard-coding-system 'euc-jp-unix)
-	  (if (not window-system) (set-terminal-coding-system 'euc-jp-unix))
-        )
-        ; emacs20 ξ
-        (progn
-	  (set-language-environment "Japanese")
-	  (set-default-coding-systems 'euc-japan-unix)
-	  (set-keyboard-coding-system 'euc-japan-unix)
-	  (if (not window-system) (set-terminal-coding-system 'euc-japan-unix))
-        )
-    )
-)
+(if (featurep 'mule)
+    (progn
+      (set-language-environment "Japanese")
+      (prefer-coding-system 'euc-jp-unix)
+      (set-keyboard-coding-system 'euc-jp-unix)
+      (if (not window-system) (set-terminal-coding-system 'euc-jp-unix))
+      ;;
+      ))
 ; ܸ info ʸʤ褦
 (auto-compression-mode t)
 ; xemacs  shell-mode  ܸ EUC Ȥ褦ˤ
@@ -33,8 +23,8 @@ print <<'EOF';
        (lambda () (set-buffer-process-coding-system 'euc-japan 'euc-japan))))
 )
 ; ܸ grep
-(if (file-exists-p "/usr/bin/jgrep")
-    (setq grep-command "jgrep -n -e ")
+(if (file-exists-p "/usr/bin/lgrep")
+    (setq grep-command "lgrep -n ")
 )
 EOF
 
@@ -120,10 +110,8 @@ sub emacs_skk($) {
 	print
 		"(set-input-method \"japanese-skk\")\n" .
 		"(toggle-input-method nil)\n";
-	if (isinstalled("xemacs21.*")) {
-		if (!isinstalled("xemacs21-mule.*")) {
-			addlist("xemacs21-mule-canna-wnn");
-		}
+	if (!isinstalled("xemacs21-mule.*")) {
+		addlist("xemacs21-mule-canna-wnn");
 	}
 }
 
