@@ -87,7 +87,9 @@ sub isNC($$$)
 		  && !$OPT_N) {
 			print STDERR "\"jfbterm\" WO JIKKOU SHIMASUKA? [Y/n] ";
 			$a = <>;
-			exec("jfbterm -e $THIS -N -C $OPT") if ($a !~ /n|N/);
+			if ($a !~ /n|N/) {
+				(-f "/usr/X11R6/lib/X11/fonts/misc/unifont.pcf.gz") ? ($CHARMAP eq 'UTF-8' ? exec("jfbterm -q -e $THIS -N -O $OPT") : exec("jfbterm -q -c other,EUC-JP,iconv,UTF-8 -e $THIS -N -O $OPT")) : ($CHARMAP eq 'UTF-8' ? exec("jfbterm -q -c other,UTF-8,iconv,EUC-JP -e $THIS -N -O $OPT") : exec("jfbterm -q -e $THIS -N -O $OPT"));
+			}
 			$KANJI=0;
 		} else {
 			$KANJI=0;
@@ -207,15 +209,15 @@ sub initialize()
 	if (&Sub::isinstalled("tcsh")) {&Sub::addlist("tcsh-kanji");}
 #	if (&Sub::isinstalled("dvi2tty")) {&Sub::addlist("dvi2tty-ja");}
 #	if (&Sub::isinstalled("mutt")) {&Sub::addlist("mutt-ja");}
-	if (&Sub::isinstalled("slrn")) {&Sub::addlist("slrn-ja");}
+#	if (&Sub::isinstalled("slrn")) {&Sub::addlist("slrn-ja");}
 #	if (&Sub::isinstalled("tgif")) {&Sub::addlist("tgif-ja");}
-	if (&Sub::isinstalled("xjed")) {&Sub::addlist("xjed-ja");}
+#	if (&Sub::isinstalled("xjed")) {&Sub::addlist("xjed-ja");}
 	if (&Sub::isinstalled("xterm")) {&Sub::addlist("kterm");}
 	if (&Sub::isinstalled("xterm")) {
 		&Sub::addlist("kterm");
 		&Sub::addlist("xutils");
 	}
-	if (&Sub::isinstalled("rxvt")) {&Sub::addlist("rxvt-beta");}
+#	if (&Sub::isinstalled("rxvt")) {&Sub::addlist("rxvt-beta");}
 	if (&Sub::isinstalled("nethack")) {&Sub::addlist("jnethack");}
 	if (&Sub::isinstalled("doc-debian")) {&Sub::addlist("doc-debian-ja");}
 	if (&Sub::isinstalled("apt-howto")) {&Sub::addlist("apt-howto-ja");}
@@ -225,17 +227,17 @@ sub initialize()
 	if (&Sub::isinstalled("doc-linux-html")) {
 		&Sub::addlist("doc-linux-ja-html");
 	}
-	if (&Sub::isinstalled("vim")) {
-		&Sub::addlist("jvim-canna");
-	}
-	if (&Sub::isinstalled("nvi") && !&Sub::isinstalled("nvi-m17n") && 
-	 !&Sub::isinstalled("nvi-m17n-canna")) {
-		if ($Sub::IM_DEFAULT eq "Canna") {
-			&Sub::addlist("nvi-m17n-canna");
-		} else {
-			&Sub::addlist("nvi-m17n");
-		}
-	}
+#	if (&Sub::isinstalled("vim")) {
+#		&Sub::addlist("jvim-canna");
+#	}
+	#if (&Sub::isinstalled("nvi") && !&Sub::isinstalled("nvi-m17n") && 
+	# !&Sub::isinstalled("nvi-m17n-canna")) {
+	#	if ($Sub::IM_DEFAULT eq "Canna") {
+	#		&Sub::addlist("nvi-m17n-canna");
+	#	} else {
+	#		&Sub::addlist("nvi-m17n");
+	#	}
+	#}
 	if (&Sub::isinstalled("xserver-.*")) {
 #		&Sub::addlist("xfonts-cjk");    not used since woody
 		&Sub::addlist("xbase-clients"); # xprop in .bashrc/.cshrc
@@ -331,6 +333,9 @@ sub sourceset2displayset ($)
 	my ($a, $b, $r);
 	$a = $_[0];
 	if ($KANJIMODE == 2) {return &sourceset2utf8($a);}
+	return $a; # $a is EUC-JP.
+	# ʲJISѴɤϡ EUCɽǤʤǶüǤˤʤ
+	# ΤᡢΥСǤϤΥɤ¹Ԥ뤳ȤϤʤ
 	$r = "";
 	while (length($a) != 0) {
 		$a =~ /^([\0-\177]*)(.*)/s;
