@@ -17,7 +17,7 @@ sub initialize()
 	&Sub::addlist("locales");
 	&Sub::addlist("manpages-ko");
 	if (&Sub::isinstalled("xserver-.*")) {
-		&Sub::addlist("ami");
+		&Sub::addlist("nabi");
 		&Sub::addlist("hanterm");
 		&Sub::addlist("xfonts-baekmuk");
 	}
